==> mautrix-0.4.0.dev43-py3-none-any.whl: mautrix/types.py <==
# Copyright (c) 2018 Tulir Asokan
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
from .api.http import JSON, Method, APIPath

from .client.api.types import (
    UserID, EventID, RoomID, RoomAlias, FilterID, ContentURI, SyncToken,

    Filter, EventFilter, RoomFilter, RoomEventFilter,

    EventType, RedactionEvent, RedactionEventContent,
    MessageEvent, MessageEventContent, MessageUnsigned, MediaMessageEventContent,
    LocationMessageEventContent, LocationInfo, InReplyTo, MessageType, Format, MediaInfo, FileInfo,
    AudioInfo, VideoInfo, ImageInfo, ThumbnailInfo, TextMessageEventContent,
    BaseMessageEventContent, RelatesTo, PowerLevelStateEventContent, Membership,
    MemberStateEventContent, StateEvent, AliasesStateEventContent, CanonicalAliasStateEventContent,
    StrippedStateEvent, RoomNameStateEventContent, RoomTopicStateEventContent,
    RoomPinnedEventsStateEventContent, StateUnsigned, RoomAvatarStateEventContent,
    StateEventContent, AccountDataEvent, AccountDataEventContent, RoomTagInfo,
    RoomTagAccountDataEventContent, Event, EventContent, BaseFileInfo, PresenceEventContent,
    PresenceState, TypingEventContent, TypingEvent, PresenceEvent, PresenceState,
    SingleReceiptEventContent, ReceiptEventContent, ReceiptEvent, ReceiptType, GenericEvent,
    Obj, Lst, RoomTombstoneEventContent,

    User, Member, UserSearchResults,

    MediaRepoConfig, MXOpenGraph, OpenGraphVideo, OpenGraphImage, OpenGraphAudio,

    SerializerError, Serializable, SerializableEnum, SerializableAttrs, serializer, deserializer)

==> mautrix-0.5.0b1-py3-none-any.whl: mautrix/types.py <==
# Copyright (c) 2020 Tulir Asokan
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
from .api.http import JSON, Method, APIPath

from .client.api.types import (
    UserID, EventID, RoomID, RoomAlias, FilterID, ContentURI, SyncToken,

    Filter, EventFilter, RoomFilter, RoomEventFilter,

    EventType, RedactionEvent, RedactionEventContent, ReactionEventContent, ReactionEvent,
    MessageEvent, MessageEventContent, MessageUnsigned, MediaMessageEventContent,
    LocationMessageEventContent, LocationInfo, RelationType, MessageType, Format, MediaInfo,
    FileInfo, AudioInfo, VideoInfo, ImageInfo, ThumbnailInfo, TextMessageEventContent,
    BaseMessageEventContent, RelatesTo, PowerLevelStateEventContent, Membership,
    MemberStateEventContent, StateEvent, AliasesStateEventContent, CanonicalAliasStateEventContent,
    StrippedStateEvent, RoomNameStateEventContent, RoomTopicStateEventContent,
    RoomPinnedEventsStateEventContent, StateUnsigned, RoomAvatarStateEventContent,
    StateEventContent, AccountDataEvent, AccountDataEventContent, RoomTagInfo,
    RoomTagAccountDataEventContent, Event, EventContent, BaseFileInfo, PresenceEventContent,
    PresenceState, TypingEventContent, TypingEvent, PresenceEvent, PresenceState,
    SingleReceiptEventContent, ReceiptEventContent, ReceiptEvent, ReceiptType, GenericEvent,
    Obj, Lst, RoomTombstoneEventContent,

    RoomCreatePreset, RoomDirectoryVisibility, PaginationDirection, RoomAliasInfo,
    RoomDirectoryResponse, DirectoryPaginationToken, PaginatedMessages,

    User, Member, UserSearchResults,

    MediaRepoConfig, MXOpenGraph, OpenGraphVideo, OpenGraphImage, OpenGraphAudio,

    SerializerError, Serializable, SerializableEnum, SerializableAttrs, serializer, deserializer)
